/*
 * BLMenuType.java
 *
 * Created on March 5, 2008, 11:05 AM
 *
 * To change this template, choose Tools | Template Manager
 * and open the template in the editor.
 */

package org.biolegato.core.plugintypes;

import org.biolegato.core.main.BLMain;

/**
 * An interface for menu reader objects.  All subclasses are expected to parse menu objects into BioLegato.
 *
 * @author Graham Alvare
 * @author Brian Fristensky
 */
public abstract class MenuType {
    /**
     * Reads a menu into the given window/menu instances.
     */
    public static void loadMenu () {}
}